<?php
/**
 * Adds layout options on posts and pages.
 *
 * @package WPstart
 * @since WPstart 1.1.5
 */
 
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
* Adds a box to the side column on the Page and Post edit screens.
*/
function wpstart_post_custom_meta_layout_add_meta_box() {
	$post_types = array( 'page', 'post' );
	
	foreach ( $post_types as $post_type ) {
		add_meta_box( 
			'wpstart_post_custom_meta_layout_meta_box', 
			__( 'Layout', 'wpstart' ), 
			'wpstart_post_custom_meta_layout_meta_box', 
			$post_type, 
			'side', 
			'default' 
		);
    }
}
add_action( 'add_meta_boxes', 'wpstart_post_custom_meta_layout_add_meta_box' );

/**
* wpstart_post_custom_meta_layout_meta_box function.
*/
function wpstart_post_custom_meta_layout_meta_box() {
	global $post;
	$custom        = ( get_post_custom( $post->ID ) ? get_post_custom( $post->ID ) : false );
	$layout        = ( isset( $custom['_wpstart_layout'][0] ) ? $custom['_wpstart_layout'][0] : 'default' );
	$valid_layouts = wpstart_post_custom_meta_layout_get_valid_layouts();
	?>
	<p>
		<label><input type="radio" name="_wpstart_layout" <?php checked( 'default' == $layout ); ?> value="default" />
		<?php _e( 'Default', 'wpstart' ); ?></label><br/>
		<?php foreach( $valid_layouts as $slug => $name ) { ?>
			<label><input type="radio" name="_wpstart_layout" <?php checked( $slug == $layout ); ?> value="<?php echo $slug; ?>" />
			<?php echo $name; ?></label><br/>
		<?php } ?>
	</p>
<?php
}

/**
* wpstart_post_custom_meta_layout_save_post_metadata function.
*/
function wpstart_post_custom_meta_layout_save_post_metadata() {
	global $post;
	if( !isset( $post ) || !is_object( $post ) ) {
		return;
	}
	$valid_layouts = wpstart_post_custom_meta_layout_get_valid_layouts();
	$layout        = ( isset( $_POST['_wpstart_layout'] ) && array_key_exists( $_POST['_wpstart_layout'], $valid_layouts ) ? $_POST['_wpstart_layout'] : 'default' );

	update_post_meta( $post->ID, '_wpstart_layout', $layout );
}

// Hook the save layout post custom meta data into
// publish_{post-type}, draft_{post-type}, and future_{post-type}
add_action( 'publish_post', 'wpstart_post_custom_meta_layout_save_post_metadata' );
add_action( 'publish_page', 'wpstart_post_custom_meta_layout_save_post_metadata' );
add_action( 'draft_post', 'wpstart_post_custom_meta_layout_save_post_metadata' );
add_action( 'draft_page', 'wpstart_post_custom_meta_layout_save_post_metadata' );
add_action( 'future_post', 'wpstart_post_custom_meta_layout_save_post_metadata' );
add_action( 'future_page', 'wpstart_post_custom_meta_layout_save_post_metadata' );


/**
 * Get valid layouts.
 */
function wpstart_post_custom_meta_layout_get_valid_layouts() {
	$layouts = array(
		'template-one-column'					=> __( 'One column', 'wpstart' ),
		'template-two-columns-right-sidebar'	=> __( 'Two columns, right sidebar', 'wpstart' ),
		'template-two-columns-left-sidebar'		=> __( 'Two columns, left sidebar', 'wpstart' ),
		'template-three-columns'				=> __( 'Three columns', 'wpstart' )
	);

	return apply_filters( 'wpstart_post_custom_meta_layout_valid_layouts', $layouts );
}

/**
 * Get current layout.
 */
function wpstart_post_custom_meta_layout_get_layout() {
	/* 404 pages */
	if( is_404() ) {
		return 'default';
	}
	$layout = '';
	
	$valid_layouts = wpstart_post_custom_meta_layout_get_valid_layouts();

	global $post;
	$layout_meta_value = ( false != get_post_meta( $post->ID, '_wpstart_layout', true ) ? get_post_meta( $post->ID, '_wpstart_layout', true ) : 'default' );
	$layout_meta       = ( array_key_exists( $layout_meta_value, $valid_layouts ) ? $layout_meta_value : 'default' );	
	
	if( 'default' != $layout_meta ) {
		$layout = $layout_meta;
	} else {
		$layout = 'default';	
	}

	return apply_filters( 'wpstart_post_custom_meta_layout_get_layout', $layout );
}

/**
 * Get content classes.
 */
function wpstart_post_custom_meta_layout_get_main_classes() {
	$content_classes = array();
	$layout          = wpstart_post_custom_meta_layout_get_layout();
	
	if( in_array( $layout, array( 'default', 'template-two-columns-right-sidebar' ) ) ) {
		$content_classes[] = 'template-two-columns-right-sidebar';
	}
	else {
		if( 'template-one-column' == $layout ) {
			$content_classes[] = 'template-one-column';
		}
		else {
			if( 'template-two-columns-right-sidebar' == $layout ) {
				$content_classes[] = 'template-two-columns-right-sidebar';
			}
			else {
				if( 'template-two-columns-left-sidebar' == $layout ) {
					$content_classes[] = 'template-two-columns-left-sidebar';
				}
				else {
					if( 'template-three-columns' == $layout ) {
						$content_classes[] = 'template-three-columns';
					}
				}
			}
		}
	}

	return apply_filters( 'wpstart_post_custom_meta_layout_content_classes', $content_classes );
}

/**
 * wpstart_main_classes function.
 */
function wpstart_main_classes() {
	echo implode( ' ', wpstart_post_custom_meta_layout_get_main_classes() );
}

/**
 * wpstart_post_custom_meta_layout_wpstart_main_start_cutom_layout function.
 */
function wpstart_post_custom_meta_layout_wpstart_main_start_cutom_layout() { 
	$main_class =  implode( ' ', wpstart_post_custom_meta_layout_get_main_classes() );
	
	$main_start = "\t\t";
	$main_start .= '<div id="main" class="'. $main_class .'">';
	$main_start .= "\n\t\t\t";
	$main_start .= '<div class="container">';
	$main_start .= "\n";
	
	return $main_start;	
}
add_filter( 'wpstart_main_start', 'wpstart_post_custom_meta_layout_wpstart_main_start_cutom_layout' );
?>